pygeodesy.booleans._CompositeBase

Package pygeodesy :: Module booleans :: Class _CompositeBase |
[frames] | no frames]

# Class _CompositeBase

      object --+
               |
    named._Named --+
                   |
                  _CompositeBase

Known Subclasses:
  - _CompositeFHP
  - , _CompositeGH

(INTERNAL) Base class for BooleanFHP and BooleanGH (`_CompositeFHP` and `_CompositeGH`).

Instance Methods
__init__(self, lls, kind='', eps=2.220446049250313e-16, **name) (INTERNAL) See BooleanFHP and BooleanGH. |
__contains__(self, point) Is the `point` in one of the clips? |
__eq__(self, other) Is this composite equivalent to an `other`, i.e. |
__iter__(self) Yield all points, duplicates and intersections. |
__ne__(self, other) See method `__eq__`. |
__len__(self) Return the total number of points. |
__repr__(self) String `repr` of this composite. |
__str__(self) String `str` of this composite. |
clipids(self) Return a tuple with all `clipid`s, ordered. |
isequalTo(self, other, eps=None) Is this boolean/composite equal to an `other` within a given, non-negative tolerance? |
toLatLon(self, LatLon=None, closed=False, **LatLon_kwds) Yield all (non-duplicate) points and intersections as an instance of `LatLon`. |
Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| eps Get the null edges tolerance (`degrees`, usually).
| raiser Get the option to throw ClipError exceptions (`bool`).
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, lls, kind='', eps=2.220446049250313e-16, **name) (Constructor) |
(INTERNAL) See BooleanFHP and BooleanGH. Overrides: object.__init__

### __eq__ (self, other) (Equality operator) |
Is this composite equivalent to an `other`, i.e. do both contain equivalent clips in the same or in a different order? Two clips are considered equivalent if both have the same points etc. in the same order, possibly rotated.

### __repr__ (self) (Representation operator) |
String `repr` of this composite. Overrides: object.__repr__

### __str__ (self) (Informal representation operator) |
String `str` of this composite. Overrides: object.__str__

### isequalTo (self, other, eps=None) |
Is this boolean/composite equal to an `other` within a given, non-negative tolerance? Arguments: `other` - The other boolean/composite (`Boolean[FHP|GB]`). `eps` - Tolerance for equality (`degrees` or `None`). Returns: `True` if equivalent, `False` otherwise (`bool`). Raises: `TypeError` - Invalid `other`. See Also: Method `__eq__`.

### toLatLon (self, LatLon=None, closed=False, **LatLon_kwds) |
Yield all (non-duplicate) points and intersections as an instance of `LatLon`. Arguments: `LatLon` - Class to use (`LatLon`) or if `None`, LatLonFHP or LatLonGH. `closed` - If `True`, close each clip (`bool`). `LatLon_kwds` - Optional, additional `LatLon` keyword arguments, ignore if `LatLon is None`. Raises: `TypeError` - Invalid `LatLon`. Note: For intersections, `height` is an instance of HeightX, otherwise of Height.

Property Details

### eps Get the null edges tolerance (`degrees`, usually). Get method: eps(self) - Get the null edges tolerance (`degrees`, usually). Set method: eps(self, eps) - Set the null edges tolerance (`degrees`, usually).

### raiser Get the option to throw ClipError exceptions (`bool`). Get method: raiser(self) - Get the option to throw ClipError exceptions (`bool`). Set method: raiser(self, throw) - Set the option to throw ClipError exceptions (`bool`).